@@ -138,6 +138,12 @@ class EventRouter(AutoRepr):
     def root(self):
         return self.parent.root if self.parent else self
 
+    def detatch_child(self, child_router: EventRouter):
+        self.listeners[child_router.name].router = None
+
+    def detatch(self):
+        self.parent.detatch_child(self)
+
     def endpoint(self, name: str, decompose=False):
         def __decorator(func: ty.Callable[[...], ty.Awaitable]):
             if not asyncio.iscoroutinefunction(func):
@@ -184,23 +190,20 @@ class EventRouter(AutoRepr):
                 return self.parent.register_listener(name, listener)
             raise ValueError(f"[{self}] Attempting to register listener with invalid route {name}")
 
-        # _:target:remainder
         _, target, remainder, *_ = name.split(":", 2) + ["", ""]
         self.listeners.setdefault(target, EventMuxer(name=target))
 
-        # if target not in self.listeners:
-        #     raise ValueError(f"[{self}] No listener registered for {target} when resolving {name}. listeners: {self.listeners}")
-        # listener: ty.Union[EventFunction, EventWaiter]
         event_muxer = self.listeners[target]
         if remainder:  # target refers to a sub-router
             if sub_router := event_muxer.router:
-                sub_router.register_listener(f"{target}:{remainder}", listener)
+                return sub_router.register_listener(f"{target}:{remainder}", listener)
             else:
                 raise ValueError(f"[{self}] Attempting to descend into nonexistent subrouter {event_muxer} | {name}")
         else:  # target refers to a listener
             event_muxer.add_listener(listener)
             # self.master_lookup[listener] = event_muxer
         logging.debug("[%s] Registered! Listeners[%s] Muxer[%s] Listner [%s]", self, self.listeners, event_muxer, listener)
+        print(f"Registering!! {event_muxer} {listener}")
         return event_muxer, listener
 
         #
